// importing packages from D3 
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis
} from 'd3';
//declaring variables 
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Formatting the total value to show on the piechart
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => {
  
  const x_Axis_Value = d => d.year;
  const x_Axis_Label ='year';
  
  const y_Axis_Value = d => d.population ;
  const circleRadius = 7;
  const y_Axis_Label = 'population ';
  
  const margin = { top: 10, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;  
// Determing the Scale for X axis
  const x_Axis_Scale = scaleLinear()
    .domain(extent(data, x_Axis_Value))
    .range([0, innerWidth])
    .nice();
// Determing the Scale for Y axis  
  const y_Axis_Scale = scaleLinear()
    .domain(extent(data, y_Axis_Value))
    .range([innerHeight, 0])
    .nice();
 // POsitioning the svg element   
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 // Assigning values to x axis 
  const xAxis = axisBottom(x_Axis_Scale)
    .tickSize(-innerHeight)
    .tickPadding(10);
  
 // Assigning values to y axis  
  const yAxis = axisLeft(y_Axis_Scale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(xAxisTickFormat);
  
  const yValueG = g.append('g').call(yAxis);
  yValueG.selectAll('.domain').remove();
  // assigning label for y axis
  yValueG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(y_Axis_Label);
  
  const xValueG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  //assigning label for x axis
  xValueG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .text(x_Axis_Label);
 // To draw the line on the curve   and adding it to svg 
  const lineGenerator = line()
  	.x(d => x_Axis_Scale(x_Axis_Value(d)))
  	.y(d => y_Axis_Scale(y_Axis_Value(d)))
  	.curve(curveBasis);
 // To draw the area under the curve and adding it to svg 
  const areaGenerator = area()
  	.x(d => x_Axis_Scale(x_Axis_Value(d)))
  	.y0(innerHeight)
  	.y1(d => y_Axis_Scale(y_Axis_Value(d)))
  	.curve(curveBasis);
  // generating linechart for the data 
  g.append('path')
  	.attr('class', 'line-chart')
  	.attr('d', lineGenerator(data));
  // generating areachart for the data 
  g.append('path')
  	.attr('class', 'area-chart')
  	.attr('d', areaGenerator(data));
  
 
};
// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/Swathireddy05/aaa0eb40332301198df02c33452b02c4/raw/2343d46b6d246572e38c135da0a389791ae49ce5/Heartpatients.csv')
  .then(data => {
    data.forEach(d => {
      d.population = +d.population ;
//Formatting to retrieve year from the date
      d.year = +d.year;
    });
    render(data);
  	console.log(data);
  });